@@ -187,9 +187,14 @@ class Signals:
             df_chart = df.copy()
 
             open_col = []
+
             for i, row in df_chart.iterrows():
-                if row['logic'] == 'trade_logic':
+                ##### change #####
+                # if row['logic'] == 'trade_logic':
+                #     open_col.append(row['close'])
+                if row['trade_logic']:
                     open_col.append(row['close'])
+                ##################
                 else:
                     open_col.append(None)
 
